@@ -4,52 +4,72 @@ u"""
 контроллеры, кэш контроллеров.
 """
 
-from __future__ import absolute_import
-from __future__ import print_function
-import re
 import abc
+import importlib
 import inspect
+import re
+import six
 import threading
 import warnings
-from functools import wraps
-from importlib import import_module
-from logging import getLogger
-
-from django import http
-from django.conf import settings
-
-from .results import (
-    ActionResult,
-    PreJsonResult,
-    JsonResult,
-    HttpReadyResult,
-    TextResult,
-    XMLResult,
-    BaseContextedResult,
-    OperationResult,
-    ActionRedirectResult
+from functools import (
+    wraps,
 )
-from .exceptions import (
-    ApplicationLogicException,
-    ActionException,
-    ActionNotFoundException,
-    ActionPackNotFoundException,
-    ReinitException,
-    ActionUrlIsNotDefined
+from importlib import (
+    import_module,
+)
+from logging import (
+    getLogger,
+)
+
+from django import (
+    http,
+)
+from django.conf import (
+    settings,
+)
+from six.moves import (
+    map,
+)
+
+from m3.plugins import (
+    get_module_spec,
+)
+
+from . import (
+    utils,
 )
 from .context import (
     ActionContext,
     ActionContextDeclaration,
-    DeclarativeActionContext,
-    RequiredFailed,
     ContextBuildingError,
     CriticalContextBuildingError,
+    DeclarativeActionContext,
+    RequiredFailed,
     convert_dac_to_acd,
 )
-from .metrics import create_statsd_client
-from . import utils
-import six
-from six.moves import map
+from .exceptions import (
+    ActionException,
+    ActionNotFoundException,
+    ActionPackNotFoundException,
+    ActionUrlIsNotDefined,
+    ApplicationLogicException,
+    ReinitException,
+)
+from .metrics import (
+    create_statsd_client,
+)
+from .results import (
+    ActionRedirectResult,
+    ActionResult,
+    BaseContextedResult,
+    HttpReadyResult,
+    JsonResult,
+    OperationResult,
+    PreJsonResult,
+    TextResult,
+    XMLResult,
+)
+
 
 _STATSD_CLIENT = create_statsd_client(settings)
 ACD = ActionContextDeclaration
@@ -1676,13 +1696,15 @@ class ControllerCache(object):
             cls.overrides = {}
             procs = []
             for app_name in settings.INSTALLED_APPS:
-                try:
-                    module = import_module('.app_meta', app_name)
-                except ImportError as err:
-                    if err.args[0].find('No module named') == -1:
-                        raise
+                script_path = f'{app_name}.app_meta'
+
+                module_spec = get_module_spec(script_path)
+
+                if not module_spec:
                     continue
 
+                module = importlib.import_module(script_path)
+
                 # расширение словаря overridde'ов
                 for original_cls, new_inst in (
                     six.iteritems(getattr(module, 'action_pack_overrides', {}))
