@@ -45,18 +45,19 @@ def _date2str(*args):
     )
     return date2str(*args)
 
-#============================= ИСКЛЮЧЕНИЯ =====================================
+
+# ============================= ИСКЛЮЧЕНИЯ =====================================
 class ActionContextException(Exception):
     """ Базовый класс для исключений контекста """
     pass
 
 
 class RequiredFailed(ActionContextException):
-    u'''
+    u"""
     Исключительная ситуация, которая выбрасывается в случае
     если фактическое наполнение контекста действия не соответствует
     описанным правилам
-    '''
+    """
     def __init__(self, reason):
         self.reason = reason
 
@@ -125,7 +126,7 @@ class CriticalContextBuildingError(ContextBuildingError):
     pass
 
 
-#================================== ПАРСЕРЫ ===================================
+# ================================== ПАРСЕРЫ ===================================
 def _make_datetime_parser(extractor, formats):
     def parse(value):
         for (fmt, length) in formats:
@@ -232,7 +233,7 @@ _PARSERS = {
 }
 
 
-#================================== КЛАССЫ ====================================
+# ================================== КЛАССЫ ====================================
 
 # "Стражник" для значения по умолчанию ActionContextDeclaration.
 _none = object()
@@ -272,7 +273,7 @@ class ActionContextDeclaration(object):
         return self.verbose_name if self.verbose_name else self.name
 
 
-class AbstractModelPKType(object, metaclass=ABCMeta):
+class AbstractModelPKType(six.with_metaclass(ABCMeta, object)):
     """
     Абстрактный класс для создания парсеров первичных ключей и приведения к
     типу, указанному в моделе
@@ -287,7 +288,6 @@ class AbstractModelPKType(object, metaclass=ABCMeta):
         self._model_name = model_name
         self._model = None
 
-
     def __call__(
         self,
         raw_value,
@@ -338,7 +338,10 @@ class ModelSinglePKType(AbstractModelPKType):
         Пасинг сырой строки для выделения первичного ключа и приведения его к
         указанному в моделе типу
         """
-        raw_value = self._parse_obj_id(raw_value)
+        # TODO: BOBUH-17847 В _parse_obj_id производится разбор строки, но если использовать редирект, могут прийти уже преобразованные
+        #   данные к нужным типам не являющимися строками
+        if isinstance(raw_value, str):
+            raw_value = self._parse_obj_id(raw_value)
 
         return self.model._meta.pk.to_python(raw_value)
 
@@ -356,6 +359,14 @@ class ModelSinglePKType(AbstractModelPKType):
 
         return raw_value
 
+    def __str__(self):
+        if self.app_label and self.model_name:
+            str_ = 'id for {}.{}'.format(self.app_label, self.model_name)
+        else:
+            str_ = 'id for unknown model'
+
+        return str_
+
 
 class ModelMultiplePKType(AbstractModelPKType):
     """
@@ -374,6 +385,14 @@ class ModelMultiplePKType(AbstractModelPKType):
 
         return list(map(self.model._meta.pk.to_python, pks))
 
+    def __str__(self):
+        if self.app_label and self.model_name:
+            str_ = 'ids for {}.{}'.format(self.app_label, self.model_name)
+        else:
+            str_ = 'ids for unknown model'
+
+        return str_
+
 
 class ActionContext(object):
     """
@@ -382,7 +401,7 @@ class ActionContext(object):
     #: Для совместимости
     RequiredFailed = RequiredFailed
 
-    class ValuesList():
+    class ValuesList(object):
         u"""
         Класс для описания параметров, которые будут передаваться в виде
         списка значений, разделенных определенным символом
@@ -418,7 +437,7 @@ class ActionContext(object):
             elif isinstance(arg_type, AbstractModelPKType):
                 value = arg_type(raw_value)
             else:
-                if not arg_type in _PARSERS:
+                if arg_type not in _PARSERS:
                     raise TypeError('Unknown parser "%r"!' % arg_type)
                 value = _PARSERS[arg_type](raw_value)
         except AssertionError:
@@ -427,17 +446,17 @@ class ActionContext(object):
         return value
 
     def build(self, request, rules):
-        u'''
+        u"""
         Выполняет заполнение собственных атрибутов
         согласно переданному запросу, исходя из списка правил
 
         :param request:запрос, на основе которого производится
             заполнение контекста
-        :type reques: django.http.Request
+        :type request: django.http.Request
 
         :param rules: правила извлечения контекста из запроса
         :type rules: список m3_core.actions.context.ActionContextDeclaration
-        '''
+        """
 
         params = {}
         if rules:
@@ -469,7 +488,7 @@ class ActionContext(object):
             # в следствии этого происходит ошибка
             # IOError: request data read error
             logger.warning(str(err))
-        except ValueError as err:
+        except ValueError:
             # если ошибка преобразования,
             # то пусть проставится значение по-умолчанию
             logger.exception(
@@ -551,7 +570,7 @@ class ActionContext(object):
         return result
 
 
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 class DeclarativeActionContext(ActionContext):
     """
     ActionContext, использующий декларативное описание контекста
@@ -602,7 +621,7 @@ class DeclarativeActionContext(ActionContext):
 
         :param request:запрос, на основе которого производится
             заполнение контекста
-        :type reques: django.http.Request
+        :type request: django.http.Request
 
         :param rules: правила извлечения контекста из запроса
         :type rules: список m3_core.actions.context.ActionContextDeclaration
@@ -685,12 +704,11 @@ class DeclarativeActionContext(ActionContext):
         cls._parsers[name] = parser
 
     @classmethod
-    def matches(self, data):
+    def matches(cls, data):
         """
         Возвращает True, если объект data "похож" на правила для
         DeclarativeActionContext
         :param data: проверяемый объект
-        :param type: object
 
         :return: True, если data "похож" на набор правил
         :rtype: boolean
@@ -711,4 +729,4 @@ def convert_dac_to_acd(dac):
     return [
         ActionContextDeclaration(name=name, **rules)
         for name, rules in dac.items()
-    ]
\ No newline at end of file
+    ]
