@@ -1,16 +1,11 @@
-#coding:utf-8
-"""
-Created on 29.01.2011
+# coding: utf-8
 
-@author: akvarats
-"""
-
-from django.db import transaction
+from __future__ import absolute_import
 from django.conf import settings
 
-
 from m3 import RelatedError
 from m3.db import BaseObjectModel, safe_delete
+from m3_django_compat import get_request_params, atomic
 
 from m3.actions import (
     ActionPack, Action, PreJsonResult, OperationResult,
@@ -21,8 +16,7 @@ from m3.actions.results import ActionResult
 from m3.actions.interfaces import IMultiSelectablePack
 from m3_ext.ui.windows.complex import ExtDictionaryWindow
 from m3_ext.ui.misc.store import ExtJsonStore
-class ExtUIScriptResult: pass
-
+from m3_ext.ui.results import ExtUIScriptResult
 from m3_legacy import logger
 
 try:
@@ -250,9 +244,10 @@ class DictRowsAction(Action):
     def run(self, request, context):
         offset = utils.extract_int(request, 'start')
         limit = utils.extract_int(request, 'limit')
-        filter = request.REQUEST.get('filter')
-        direction = request.REQUEST.get('dir')
-        user_sort = request.REQUEST.get('sort')
+        request_params = get_request_params(request)
+        filter = request_params.get('filter')
+        direction = request_params.get('dir')
+        user_sort = request_params.get('sort')
         if direction == 'DESC':
             user_sort = '-' + user_sort
         dict_list = []
@@ -672,7 +667,7 @@ class BaseDictionaryModelActions(BaseDictionaryActions):
                 return None
         return record
 
-    @transaction.commit_on_success
+    @atomic
     def save_row(self, obj):
         obj.save()
         return OperationResult(success=True)
@@ -681,7 +676,7 @@ class BaseDictionaryModelActions(BaseDictionaryActions):
         # Такая реализация обусловлена тем,
         # что IntegrityError невозможно отловить
         # до завершения транзакции, и приходится оборачивать транзакцию.
-        @transaction.commit_on_success
+        @atomic
         def delete_row_in_transaction(self, objs):
             message = ''
             if len(objs) == 0:
@@ -693,7 +688,7 @@ class BaseDictionaryModelActions(BaseDictionaryActions):
                         callable(obj.safe_delete))):
                         try:
                             obj.safe_delete()
-                        except RelatedError, e:
+                        except RelatedError as e:
                             message = e.args[0]
                     else:
                         if not safe_delete(obj):
@@ -705,7 +700,7 @@ class BaseDictionaryModelActions(BaseDictionaryActions):
         # Тут пытаемся поймать ошибку из транзакции.
         try:
             return delete_row_in_transaction(self, objs)
-        except Exception, e:
+        except Exception as e:
             # Встроенный в Django IntegrityError
             # не генерируется. Кидаются исключения
             # специфичные для каждого драйвера БД.
@@ -795,7 +790,7 @@ class BaseEnumerateDictionary(BaseDictionaryActions):
             'Attribute enumerate_class is not defined.')
         data = []
         # сортировка по ключам
-        keys = self.enumerate_class.values.keys()
+        keys = list(self.enumerate_class.values.keys())
         keys.sort()
 
         for k in keys:
@@ -814,7 +809,7 @@ class BaseEnumerateDictionary(BaseDictionaryActions):
         сам id хранится в БД
         """
         assert isinstance(id, int)
-        assert id in self.enumerate_class.keys(), (
+        assert id in list(self.enumerate_class.keys()), (
             'Enumarate key "%s" is not'
             ' defined in %s' % (id, self.enumerate_class))
         return id
