@@ -1,18 +1,15 @@
-# coding:utf-8
+#coding:utf-8
 '''
 Интерфейсы
 ++++++++++
 '''
 
 from __future__ import absolute_import
-
-from abc import ABCMeta
-from abc import abstractmethod
-
-from six import with_metaclass
+from abc import ABCMeta, abstractmethod
+import six
 
 
-class ISelectablePack(with_metaclass(ABCMeta, object)):
+class ISelectablePack(six.with_metaclass(ABCMeta, object)):
     """
     Интерфейс pack-классов для выбора значений из полей ExtDictSelectField
     """
