@@ -1,16 +1,24 @@
 # coding: utf-8
 u"""Хелперы для отработки расширяемых конфигураций url'ов."""
 
-from __future__ import absolute_import
+import collections
 import inspect
 import warnings
-import collections
-from importlib import import_module
 
-from django.conf import settings
+from django.urls import (
+    URLPattern,
+)
 
-from m3 import caching
-from m3.actions import ControllerCache, Action
+from m3 import (
+    caching,
+)
+from m3.actions import (
+    Action,
+    ControllerCache,
+)
+from m3.plugins import (
+    get_callables_from_modules,
+)
 
 
 def _get_instance(obj):
@@ -27,31 +35,20 @@ def _get_instance(obj):
     return obj
 
 
-def get_app_urlpatterns():
+def get_app_urlpatterns() -> list[URLPattern]:
     """
     Возвращает конфигурацию урлов, объявленных в app_meta приложений.
 
     Данная функция не проглатывает ошибки, а выбрасывает все наружу.
-    Перехват исключительных ситуаций данной фунции необходимо осуществлять
+    Перехват исключительных ситуаций данной функции необходимо осуществлять
     вручную в urls.py прикладных приложений
     """
     
-    url_patterns = []
+    url_patterns: list[URLPattern] = []
+    procs: list[callable] = get_callables_from_modules('app_meta', 'register_urlpatterns')
 
-    for app_name in settings.INSTALLED_APPS:
-        try:
-            module = import_module('.app_meta', app_name)
-        except ImportError as err:
-            # по идее, такая ошибка возникает в
-            # случае, если у нас для
-            # установленного приложения
-            # нет модуля app_meta.py
-            if err.args[0].find('No module named') == -1:
-                raise
-            continue
-        proc = getattr(module, 'register_urlpatterns', None)
-        if callable(proc):
-            url_patterns += proc()
+    for proc in procs:
+        url_patterns += proc()
 
     return url_patterns
 
