@@ -1,15 +1,30 @@
-# coding:utf-8
-u""""Вспомогательные функции используемые в паках."""
-from __future__ import absolute_import
+"""Вспомогательные функции используемые в паках."""
 import json
 
-from django.db import models
-from django.db.models.query_utils import Q
-from m3_django_compat import get_request_params
+from django.db import (
+    models,
+)
+from django.db.models.query_utils import (
+    Q,
+)
+from django.http import (
+    Http404,
+)
+from django.shortcuts import (
+    get_object_or_404,
+)
+from six.moves import (
+    map,
+    range,
+)
 
-from .exceptions import ApplicationLogicException
-from six.moves import map
-from six.moves import range
+from m3_django_compat import (
+    get_request_params,
+)
+
+from m3.actions.exceptions import (
+    ApplicationLogicException,
+)
 
 
 def apply_sort_order(query, columns, sort_order):
@@ -234,7 +249,9 @@ def safe_delete_record(model, id=None):
         stacklevel=2
     )
 
-    from m3.db import safe_delete
+    from m3.db import (
+        safe_delete,
+    )
     assert (isinstance(model, models.Model) or issubclass(model, models.Model))
     assert (isinstance(id, int) or isinstance(id, int) or id is None)
 
@@ -433,3 +450,25 @@ def apply_column_filter(query, request, map):
     if cond:
         query = query.filter(cond)
     return query
+
+
+def get_object_or_application_logic_exc(model, *args, **kwargs):
+    """Обёртка для встроенного шортката get_object_or_404.
+
+    Args:
+        model: класс модели
+        *args: аргументы для get().
+        **kwargs: аргументы для get().
+
+    Returns: полученный объект указанной модели
+
+    Raises: вызывает исключение ApplicationLogicException в случаях, если записи не существует или
+        существует больше чем 1 запись
+    """
+
+    try:
+        result = get_object_or_404(model, *args, **kwargs)
+    except (Http404, model.MultipleObjectsReturned):
+        raise ApplicationLogicException('Получено ноль или несколько записей!')
+
+    return result
