@@ -1,11 +1,16 @@
 # coding: utf-8
 
-from __future__ import absolute_import
+import importlib
 import threading
-from logging import getLogger
-from importlib import import_module
-
-from django.conf import settings
+from importlib.machinery import (
+    ModuleSpec,
+)
+from logging import (
+    getLogger,
+)
+from django.conf import (
+    settings,
+)
 
 
 logger = getLogger('django')
@@ -94,16 +99,8 @@ class ExtensionManager:
         try:
             if self.loaded:
                 return False
-            for app_name in settings.INSTALLED_APPS:
-                try:
-                    module = import_module('.app_meta', app_name)
-                except ImportError as err:
-                    if err.args[0].find('No module named') == -1:
-                        raise
-                    continue
-                proc = getattr(module, 'register_extensions', None)
-                if callable(proc):
-                    proc()
+
+            get_and_execute_callable_from_modules('app_meta', 'register_extensions')
             self._loaded = True
         finally:
             self._write_lock.release()
@@ -247,6 +244,84 @@ def extension_point(name=''):
         # формируем определение точки расширения
         if not ExtensionManager().check_point_exists(name):
             # пытаемся добавить точку расширения
-            ExtensionManager().register_point_external(ExtensionPoint(name=name,default_listener=ExtensionHandler(f)))
+            ExtensionManager().register_point_external(ExtensionPoint(name=name, default_listener=ExtensionHandler(f)))
         return wrapper
     return inner
+
+
+def get_module_spec(script_path: str) -> ModuleSpec:
+    """Получение спецификации модуля.
+
+    Функция позволяет определить, существует ли модуль вообще.
+
+    Args:
+        script_path: str
+            Путь к импортируемому скрипту
+
+    Returns:
+        module_spec: ModuleSpec | None
+            Спецификация модуля или None, если нет *.py файла
+
+    Raises:
+        ModuleNotFoundError
+            Вызывается тогда, когда модуля не существует.
+            Например, вместо datalogging попал datalogging1.
+        ValueError
+            Вызывается когда __spec__ не существует или None
+    """
+
+    module_spec: ModuleSpec = importlib.util.find_spec(script_path)
+
+    return module_spec
+
+
+def get_callables_from_modules(script_name: str, function_name: str) -> list[callable]:
+    """Собираем все callable из модулей.
+
+    Функция импортирует модули и извлекает из них интересующие функции,
+    которые, например, регистрируют Action's.
+
+    Args:
+        function_name: str
+            Имя функции, которую нужно получить из модуля.
+        script_name: str
+            Имя *.py файла в модуле, где содержится функция с именем registration_callable_name.
+
+    Returns:
+        procs: list[callable]
+            Возвращает список функций из модулей.
+    """
+
+    procs: list[callable] = []
+
+    for app_name in settings.INSTALLED_APPS:
+        script_path: str = f'{app_name}.{script_name}'
+
+        module_spec: ModuleSpec = get_module_spec(script_path)
+
+        if not module_spec:
+            continue
+
+        script_module = importlib.import_module(script_path)
+
+        proc: [callable, None] = getattr(script_module, function_name, None)
+        if callable(proc):
+            procs.append(proc)
+
+    return procs
+
+
+def get_and_execute_callable_from_modules(script_name: str, function_name: str) -> None:
+    """Собираем и вызываем функции из модулей.
+
+    Функция-шорткат для сбора всех нужных функций из модулей и их последующий вызов.
+
+    Args:
+        function_name: str
+            Имя функции, которую нужно получить из модуля.
+        script_name: str
+            Имя *.py файла в модуле, где содержится функция с именем registration_callable_name.
+    """
+
+    for proc in get_callables_from_modules(script_name, function_name):
+        proc()
